@@ -158,3 +158,21 @@ class FormaPagamentoConfiguracaoEnviarResource(PagamentoBaseResource):
             return {"erro": "Erro no banco de dados: {}".format(ex)}, 500
         except Exception, ex:
             return {"erro": u"Servidor: {}".format(ex)}, 500
+
+
+class FormaPagamentoAtivacao(PagamentoBaseResource):
+    def get(self, pagamento_id, conta_id):
+        self.pagamento_id = pagamento_id
+        pagamento = self.forma_de_pagamento
+        if self.retorno_tem_erro:
+            return self.retorno()
+        try:
+            pagamento_configuracao = FormaDePagamentoConfiguracao.objects.get(
+                conta_id=conta_id,
+                forma_pagamento_id=pagamento["id"]
+            )
+            return {"ativacao": pagamento_configuracao.ativador.to_dict()}
+        except (MeioDePagamentoNaoDefinido, MeioDePagamentoNaoEncontrado, PluginNaoEncontrado), ex:
+            return {"erro": u"pagador: {}".format(ex)}, 500
+        except IntegrityError, ex:
+            return {"erro": "Erro no banco de dados: {}".format(ex)}, 500
