@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from pagador.configuracao.cadastro import ValoresBase
 
 from pagador.extensao.base import Plugavel, PluginNaoEncontrado
 from repositories.configuracao import models
@@ -112,10 +113,14 @@ class FormaDePagamentoConfiguracao(models.FormaPagamentoConfiguracao, Plugavel):
 
     @property
     def formulario(self):
-        try:
-            return self.plugin_configuracao.MeioPagamentoFormulario()
-        except AttributeError:
-            raise PluginNaoEncontrado(u"O meio de pagamento {} (id={}) não possui a classe configuracao.MeioPagamentoFormulario.".format(self.forma_pagamento.codigo, self.forma_pagamento.id))
+        if not hasattr(self, "_formulario"):
+            self._formulario = None
+        if not self._formulario:
+            try:
+                self._formulario = self.plugin_configuracao.Formulario()
+            except AttributeError:
+                raise PluginNaoEncontrado(u"O meio de pagamento {} (id={}) não possui a classe configuracao.Formulario.".format(self.forma_pagamento.codigo, self.forma_pagamento.id))
+        return self._formulario
 
     @property
     def script(self):
@@ -131,31 +136,38 @@ class FormaDePagamentoConfiguracao(models.FormaPagamentoConfiguracao, Plugavel):
         except AttributeError:
             raise PluginNaoEncontrado(u"O meio de pagamento '{}' não possui a classe configuracao.MeioPagamentoSelecao.".format(self.forma_pagamento.codigo))
 
+    @property
+    def ativador(self):
+        try:
+            return self.plugin_seguranca.Ativador()
+        except AttributeError:
+            raise PluginNaoEncontrado(u"O meio de pagamento '{}' não possui a classe seguranca.Ativador.".format(self.forma_pagamento.codigo))
+
     @property
     def valores(self):
         try:
-            return self.plugin_configuracao.MeioPagamentoValores(self)
+            return ValoresBase(self, self.formulario)
         except AttributeError:
             raise PluginNaoEncontrado(u"O meio de pagamento '{}' não possui a classe configuracao.MeioPagamentoValores.".format(self.forma_pagamento.codigo))
 
     @property
-    def ajuda(self):
+    def cadastro(self):
         try:
-            return self.plugin_configuracao.MeioPagamentoAjuda()
+            return self.plugin_configuracao.MeioPagamentoCadastro()
         except AttributeError:
             return None
             #FIXME: Pensar em um modelo melhor para determinar extensoes não obrigatórias
-            # raise PluginNaoEncontrado(u"O meio de pagamento '{}' não possui a classe configuracao.MeioPagamentoAjuda.".format(self.forma_pagamento.codigo))
+            # raise PluginNaoEncontrado(u"O meio de pagamento '{}' não possui a classe configuracao.MeioPagamentoCadastro.".format(self.forma_pagamento.codigo))
 
     def salvar(self, dados):
         self.formulario.define_valores_em_model(self, dados).save()
 
     def to_dict(self):
-        ajuda = None
-        if self.ajuda:
-            ajuda = self.ajuda.to_dict()
+        cadastro = None
+        if self.cadastro:
+            cadastro = self.cadastro.to_dict()
         return {
-            "ajuda": ajuda,
+            "cadastro": cadastro,
             "valores": self.valores.to_dict(),
             "formulario": self.formulario.to_dict()
         }
