@@ -12,11 +12,13 @@ def envia_alteracao_de_situacao_de_pedido(pedido_numero, situacao):
 def grava_evidencia_envio(meio_pagamento, para, dados, resposta):
     if settings.GRAVA_EVIDENCIA:
         evidencia = {
-            "tipo_evidencia": "api_pagador_envio_pagamento",
+            "tipo_evidencia": "pagador-envio",
             "evidencia": {
                 "meio_pagamento": meio_pagamento,
-                "url_meio_pagamento": para,
-                "dados_enviados": dados,
+                "envio": {
+                    "dados": dados,
+                    "url":  para
+                },
                 "resposta": resposta
             }
         }
