@@ -37,9 +37,10 @@ class EnviarPedido(Plugavel):
             credenciador = Credenciais(self.meio_pagamento, self.configuracao_pagamento)
             self.headers.update(credenciador.por_cabecalho_http())
         dados = self.requisicao.dados
+        dados_envio = dados
         if type(dados is dict):
-            dados = json.dumps(dados)
-        resposta = requests.post(self.requisicao.url, data=dados, headers=self.headers)
+            dados_envio = json.dumps(dados)
+        resposta = requests.post(self.requisicao.url, data=dados_envio, headers=self.headers)
         resposta = self.processar_resposta(resposta)
         notificador.grava_evidencia_envio(self.meio_pagamento, para=self.requisicao.url, dados=dados, resposta=resposta)
         return resposta
